akhdefo_functions.Mosaic — akhdefo 2023 documentation

# akhdefo_functions.Mosaic

akhdefo_functions.Mosaic(Path_to_WorkingDir='', output_MosaicDir='', img_mode=(0, 1))

  This program mosiacs raster images in geotif format as well grab dates the satellite image taken for further processing.

  The current version only supports Planet Labs SurfaceReflectance products.

  Path_to_WorkingDir=r””

  output_MosaicDir=r””

  img_mode=(0,1) if img_mode=0 the the programs mosaics only the raster images.

  if img_mode=1 the program mosiacs only mask rasters